==> symfony_5.4.23+dfsg.orig.tar.xz: symfony-5.4.23/src/Symfony/Component/Intl/Resources/data/regions/cv.php <==
<?php

return [
    'Names' => [
        'AD' => 'Андорра',
        'AE' => 'Арапсен Пӗрлешӳллӗ Эмирачӗ',
        'AF' => 'Афганистан',
        'AG' => 'Антигуа тата Барбуда',
        'AI' => 'Ангилья',
        'AL' => 'Албани',
        'AM' => 'Армени',
        'AO' => 'Ангола',
        'AQ' => 'Антарктида',
        'AR' => 'Аргентина',
        'AS' => 'Америка Самоа',
        'AT' => 'Австри',
        'AU' => 'Австрали',
        'AW' => 'Аруба',
        'AX' => 'Аланди утравӗсем',
        'AZ' => 'Азербайджан',
        'BA' => 'Боснипе Герцеговина',
        'BB' => 'Барбадос',
        'BD' => 'Бангладеш',
        'BE' => 'Бельги',
        'BF' => 'Буркина-Фасо',
        'BG' => 'Болгари',
        'BH' => 'Бахрейн',
        'BI' => 'Бурунди',
        'BJ' => 'Бенин',
        'BL' => 'Сен-Бартелеми',
        'BM' => 'Бермуд утравӗсем',
        'BN' => 'Бруней-Даруссалам',
        'BO' => 'Боливи',
        'BQ' => 'Бонэйр, Синт-Эстатиус тата Саба',
        'BR' => 'Бразили',
        'BS' => 'Пахам утравӗсем',
        'BT' => 'Бутан',
        'BV' => 'Буве утравӗ',
        'BW' => 'Ботсвана',
        'BY' => 'Беларуҫ',
        'BZ' => 'Белиз',
        'CA' => 'Канада',
        'CC' => 'Кокос утравӗсем',
        'CD' => 'Конго - Киншаса',
        'CF' => 'Тӗп Африка Республики',
        'CG' => 'Конго - Браззавиль',
        'CH' => 'Швейцари',
        'CI' => 'Кот-д’Ивуар',
        'CK' => 'Кук утравӗсем',
        'CL' => 'Чили',
        'CM' => 'Камерун',
        'CN' => 'Китай',
        'CO' => 'Колумби',
        'CR' => 'Коста-Рика',
        'CU' => 'Куба',
        'CV' => 'Кабо-Верде',
        'CW' => 'Кюрасао',
        'CX' => 'Раштав утравӗ',
        'CY' => 'Кипр',
        'CZ' => 'Чехи',
        'DE' => 'Германи',
        'DJ' => 'Джибути',
        'DK' => 'Дани',
        'DM' => 'Доминика',
        'DO' => 'Доминикан Республики',
        'DZ' => 'Алжир',
        'EC' => 'Эквадор',
        'EE' => 'Эстони',
        'EG' => 'Египет',
        'EH' => 'Анӑҫ Сахара',
        'ER' => 'Эритрей',
        'ES' => 'Испани',
        'ET' => 'Эфиопи',
        'FI' => 'Финлянди',
        'FJ' => 'Фиджи',
        'FK' => 'Фолкленд утравӗсем',
        'FM' => 'Микронези',
        'FO' => 'Фарер утравӗсем',
        'FR' => 'Франци',
        'GA' => 'Габон',
        'GB' => 'Аслӑ Британи',
        'GD' => 'Гренада',
        'GE' => 'Грузи',
        'GF' => 'Франци Гвиана',
        'GG' => 'Гернси',
        'GH' => 'Гана',
        'GI' => 'Гибралтар',
        'GL' => 'Гренланди',
        'GM' => 'Гамби',
        'GN' => 'Гвиней',
        'GP' => 'Гваделупа',
        'GQ' => 'Экваториаллӑ Гвиней',
        'GR' => 'Греци',
        'GS' => 'Кӑнтӑр Георги тата Сандвичев утравӗсем',
        'GT' => 'Гватемала',
        'GU' => 'Гуам',
        'GW' => 'Гвиней-Бисау',
        'GY' => 'Гайана',
        'HK' => 'Гонконг (САР)',
        'HM' => 'Херд тата Макдональд утравӗ',
        'HN' => 'Гондурас',
        'HR' => 'Хорвати',
        'HT' => 'Гаити',
        'HU' => 'Венгри',
        'ID' => 'Индонези',
        'IE' => 'Ирланди',
        'IL' => 'Израиль',
        'IM' => 'Мэн утравӗ',
        'IN' => 'Инди',
        'IO' => 'Британин территори Инди океанӗре',
        'IQ' => 'Ирак',
        'IR' => 'Иран',
        'IS' => 'Исланди',
        'IT' => 'Итали',
        'JE' => 'Джерси',
        'JM' => 'Ямайка',
        'JO' => 'Иордани',
        'JP' => 'Япони',
        'KE' => 'Кени',
        'KG' => 'Киргизи',
        'KH' => 'Камбоджа',
        'KI' => 'Кирибати',
        'KM' => 'Комор утравӗсем',
        'KN' => 'Сент-Китс тата Невис',
        'KP' => 'КХДР',
        'KR' => 'Корей Республики',
        'KW' => 'Кувейт',
        'KY' => 'Кайман утравӗсем',
        'KZ' => 'Казахстан',
        'LA' => 'Лаос',
        'LB' => 'Ливан',
        'LC' => 'Сент-Люсия',
        'LI' => 'Лихтенштейн',
        'LK' => 'Шри-Ланка',
        'LR' => 'Либери',
        'LS' => 'Лесото',
        'LT' => 'Литва',
        'LU' => 'Люксембург',
        'LV' => 'Латви',
        'LY' => 'Ливи',
        'MA' => 'Марокко',
        'MC' => 'Монако',
        'MD' => 'Молдова',
        'ME' => 'Черногори',
        'MF' => 'Сен-Мартен',
        'MG' => 'Мадагаскар',
        'MH' => 'Маршаллов утравӗсем',
        'MK' => 'Ҫурҫӗр Македони',
        'ML' => 'Мали',
        'MM' => 'Мьянма (Бирма)',
        'MN' => 'Монголи',
        'MO' => 'Макао (САР)',
        'MP' => 'Ҫурҫӗр Мариан утравӗсем',
        'MQ' => 'Мартиника',
        'MR' => 'Мавритани',
        'MS' => 'Монтсеррат',
        'MT' => 'Мальта',
        'MU' => 'Маврики',
        'MV' => 'Мальдивсем',
        'MW' => 'Малави',
        'MX' => 'Мексика',
        'MY' => 'Малайзи',
        'MZ' => 'Мозамбик',
        'NA' => 'Намиби',
        'NC' => 'Ҫӗнӗ Каледони',
        'NE' => 'Нигер',
        'NF' => 'Норфолк утравӗ',
        'NG' => 'Нигери',
        'NI' => 'Никарагуа',
        'NL' => 'Нидерланд',
        'NO' => 'Норвеги',
        'NP' => 'Непал',
        'NR' => 'Науру',
        'NU' => 'Ниуэ',
        'NZ' => 'Ҫӗнӗ Зеланди',
        'OM' => 'Оман',
        'PA' => 'Панама',
        'PE' => 'Перу',
        'PF' => 'Франци Полинези',
        'PG' => 'Папуа — Ҫӗнӗ Гвиней',
        'PH' => 'Филиппинсем',
        'PK' => 'Пакистан',
        'PL' => 'Польша',
        'PM' => 'Сен-Пьер & Микелон',
        'PN' => 'Питкэрн утравӗсем',
        'PR' => 'Пуэрто-Рико',
        'PS' => 'Палестинӑн территорийӗсем',
        'PT' => 'Португали',
        'PW' => 'Палау',
        'PY' => 'Парагвай',
        'QA' => 'Катар',
        'RE' => 'Реюньон',
        'RO' => 'Румыни',
        'RS' => 'Серби',
        'RU' => 'Раҫҫей',
        'RW' => 'Руанда',
        'SA' => 'Сауд Аравийӗ',
        'SB' => 'Соломон утравӗсем',
        'SC' => 'Сейшел утравӗсем',
        'SD' => 'Судан',
        'SE' => 'Швеци',
        'SG' => 'Сингапур',
        'SH' => 'Сӑваплӑ Елена утравӗ',
        'SI' => 'Словени',
        'SJ' => 'Шпицберген тата Ян-Майен',
        'SK' => 'Словаки',
        'SL' => 'Сьерра-Леоне',
        'SM' => 'Сан-Марино',
        'SN' => 'Сенегал',
        'SO' => 'Сомали',
        'SR' => 'Суринам',
        'SS' => 'Кӑнтӑр Судан',
        'ST' => 'Сан-Томе тата Принсипи',
        'SV' => 'Сальвадор',
        'SX' => 'Синт-Мартен',
        'SY' => 'Сири',
        'SZ' => 'Эсватини',
        'TC' => 'Тёркс тата Кайкос утравӗсем',
        'TD' => 'Чад',
        'TF' => 'Франци Кӑнтӑр территорийӗсем',
        'TG' => 'Того',
        'TH' => 'Таиланд',
        'TJ' => 'Таджикистан',
        'TK' => 'Токелау',
        'TL' => 'Хӗвелтухӑҫ Тимор',
        'TM' => 'Туркменистан',
        'TN' => 'Тунис',
        'TO' => 'Тонга',
        'TR' => 'Турци',
        'TT' => 'Тринидад тата Тобаго',
        'TV' => 'Тувалу',
        'TW' => 'Тайвань',
        'TZ' => 'Танзани',
        'UA' => 'Украина',
        'UG' => 'Уганда',
        'UM' => 'Тулашӗнчи утравӗсем (АПШ)',
        'US' => 'Пӗрлешӗннӗ Штатсем',
        'UY' => 'Уругвай',
        'UZ' => 'Узбекистан',
        'VA' => 'Ватикан',
        'VC' => 'Сент-Винсент тата Гренадины',
        'VE' => 'Венесуэла',
        'VG' => 'Британин Виргини утравӗсем',
        'VI' => 'Виргини утравӗсем (АПШ)',
        'VN' => 'Вьетнам',
        'VU' => 'Вануату',
        'WF' => 'Уоллис тата Футуна',
        'WS' => 'Самоа',
        'YE' => 'Йемен',
        'YT' => 'Майотта',
        'ZA' => 'Кӑнтӑр Африка Республики',
        'ZM' => 'Замби',
        'ZW' => 'Зимбабве',
    ],
];

==> symfony_7.4.5+dfsg.orig.tar.xz: symfony-7.4.5/src/Symfony/Component/Intl/Resources/data/regions/cv.php <==
<?php

return [
    'UserAssignedNames' => [
        'XK' => 'Косово',
    ],
    'Names' => [
        'AD' => 'Андорра',
        'AE' => 'Пӗрлешнӗ Араб Эмирачӗсем',
        'AF' => 'Афганистан',
        'AG' => 'Антигуапа Барбуда',
        'AI' => 'Ангилья',
        'AL' => 'Албани',
        'AM' => 'Армени',
        'AO' => 'Ангола',
        'AQ' => 'Антарктида',
        'AR' => 'Аргентина',
        'AS' => 'Америка Самойи',
        'AT' => 'Австри',
        'AU' => 'Австрали',
        'AW' => 'Аруба',
        'AX' => 'Аланд утравӗсем',
        'AZ' => 'Азербайджан',
        'BA' => 'Боснипе Герцеговина',
        'BB' => 'Барбадос',
        'BD' => 'Бангладеш',
        'BE' => 'Бельги',
        'BF' => 'Буркина-Фасо',
        'BG' => 'Болгари',
        'BH' => 'Бахрейн',
        'BI' => 'Бурунди',
        'BJ' => 'Бенин',
        'BL' => 'Сен-Бартелеми',
        'BM' => 'Бермуд утравӗсем',
        'BN' => 'Бруней',
        'BO' => 'Боливи',
        'BQ' => 'Бонэйр, Синт-Эстатиуспа Саба',
        'BR' => 'Бразили',
        'BS' => 'Багама утравӗсем',
        'BT' => 'Бутан',
        'BV' => 'Буве утравӗ',
        'BW' => 'Ботсвана',
        'BY' => 'Беларусь',
        'BZ' => 'Белиз',
        'CA' => 'Канада',
        'CC' => 'Кокос утравӗсем',
        'CD' => 'Конго',
        'CF' => 'Вӑта Африка Республики',
        'CG' => 'Конго-Браззавиль',
        'CH' => 'Швейцари',
        'CI' => 'Кот-д’Ивуар',
        'CK' => 'Кук утравӗсем',
        'CL' => 'Чили',
        'CM' => 'Камерун',
        'CN' => 'Китай',
        'CO' => 'Колумби',
        'CR' => 'Коста-Рика',
        'CU' => 'Куба',
        'CV' => 'Кабо-Верде',
        'CW' => 'Кюрасао',
        'CX' => 'Раштав утравӗ',
        'CY' => 'Кипр',
        'CZ' => 'Чехи',
        'DE' => 'Германи',
        'DJ' => 'Джибути',
        'DK' => 'Дани',
        'DM' => 'Доминика',
        'DO' => 'Доминика Республики',
        'DZ' => 'Алжир',
        'EC' => 'Эквадор',
        'EE' => 'Эстони',
        'EG' => 'Египет',
        'EH' => 'Анӑҫ Сахара',
        'ER' => 'Эритрей',
        'ES' => 'Испани',
        'ET' => 'Эфиопи',
        'FI' => 'Финлянди',
        'FJ' => 'Фиджи',
        'FK' => 'Фолкленд утравӗсем',
        'FM' => 'Микронези',
        'FO' => 'Фарер утравӗсем',
        'FR' => 'Франци',
        'GA' => 'Габон',
        'GB' => 'Аслӑ Британи',
        'GD' => 'Гренада',
        'GE' => 'Грузи',
        'GF' => 'Франци Гвиани',
        'GG' => 'Гернси',
        'GH' => 'Гана',
        'GI' => 'Гибралтар',
        'GL' => 'Гренланди',
        'GM' => 'Гамби',
        'GN' => 'Гвиней',
        'GP' => 'Гваделупа',
        'GQ' => 'Экваторти Гвинея',
        'GR' => 'Греци',
        'GS' => 'Кӑнтӑр Георгипе Кӑнтӑр Сандвич утравӗсем',
        'GT' => 'Гватемала',
        'GU' => 'Гуам',
        'GW' => 'Гвиней-Бисау',
        'GY' => 'Гайана',
        'HK' => 'Гонконг (ЯАР)',
        'HM' => 'Хердпа Макдональд утравӗсем',
        'HN' => 'Гондурас',
        'HR' => 'Хорвати',
        'HT' => 'Гаити',
        'HU' => 'Венгри',
        'ID' => 'Индонези',
        'IE' => 'Ирланди',
        'IL' => 'Израиль',
        'IM' => 'Мэн утравӗ',
        'IN' => 'Инди',
        'IO' => 'Инди океанӗнчи Британи территорийӗ',
        'IQ' => 'Ирак',
        'IR' => 'Иран',
        'IS' => 'Исланди',
        'IT' => 'Итали',
        'JE' => 'Джерси',
        'JM' => 'Ямайка',
        'JO' => 'Иордани',
        'JP' => 'Япони',
        'KE' => 'Кени',
        'KG' => 'Кӑркӑсстан',
        'KH' => 'Камбоджа',
        'KI' => 'Кирибати',
        'KM' => 'Комор утравӗсем',
        'KN' => 'Сент-Китспа Невис',
        'KP' => 'Ҫур ҫӗр Корея',
        'KR' => 'Кӑнтӑр Корея',
        'KW' => 'Кувейт',
        'KY' => 'Кайман утравӗсем',
        'KZ' => 'Казахстан',
        'LA' => 'Лаос',
        'LB' => 'Ливан',
        'LC' => 'Сент-Люси',
        'LI' => 'Лихтенштейн',
        'LK' => 'Шри-Ланка',
        'LR' => 'Либери',
        'LS' => 'Лесото',
        'LT' => 'Литва',
        'LU' => 'Люксембург',
        'LV' => 'Латви',
        'LY' => 'Ливи',
        'MA' => 'Марокко',
        'MC' => 'Монако',
        'MD' => 'Молдова',
        'ME' => 'Черногори',
        'MF' => 'Сен-Мартен',
        'MG' => 'Мадагаскар',
        'MH' => 'Маршалл утравӗсем',
        'MK' => 'Ҫур ҫӗр Македони',
        'ML' => 'Мали',
        'MM' => 'Мьянма (Бирма)',
        'MN' => 'Монголи',
        'MO' => 'Макао (ЯАР)',
        'MP' => 'Ҫур ҫӗр Мариан утравӗсем',
        'MQ' => 'Мартиника',
        'MR' => 'Мавритани',
        'MS' => 'Монтсеррат',
        'MT' => 'Мальта',
        'MU' => 'Маврики',
        'MV' => 'Мальдив',
        'MW' => 'Малави',
        'MX' => 'Мексика',
        'MY' => 'Малайзи',
        'MZ' => 'Мозамбик',
        'NA' => 'Намиби',
        'NC' => 'Ҫӗнӗ Каледони',
        'NE' => 'Нигер',
        'NF' => 'Норфолк утравӗ',
        'NG' => 'Нигери',
        'NI' => 'Никарагуа',
        'NL' => 'Нидерланд',
        'NO' => 'Норвеги',
        'NP' => 'Непал',
        'NR' => 'Науру',
        'NU' => 'Ниуэ',
        'NZ' => 'Ҫӗнӗ Зеланди',
        'OM' => 'Оман',
        'PA' => 'Панама',
        'PE' => 'Перу',
        'PF' => 'Франци Полинезийӗ',
        'PG' => 'Папуа — Ҫӗнӗ Гвинея',
        'PH' => 'Филиппин',
        'PK' => 'Пакистан',
        'PL' => 'Польша',
        'PM' => 'Сен-Пьерпа Микелон',
        'PN' => 'Питкэрн утравӗсем',
        'PR' => 'Пуэрто-Рико',
        'PS' => 'Палестина территорийӗсем',
        'PT' => 'Португали',
        'PW' => 'Палау',
        'PY' => 'Парагвай',
        'QA' => 'Катар',
        'RE' => 'Реюньон',
        'RO' => 'Румыни',
        'RS' => 'Серби',
        'RU' => 'Раҫҫей',
        'RW' => 'Руанда',
        'SA' => 'Сауд Аравийӗ',
        'SB' => 'Соломон утравӗсем',
        'SC' => 'Сейшел утравӗсем',
        'SD' => 'Судан',
        'SE' => 'Швеци',
        'SG' => 'Сингапур',
        'SH' => 'Сӑваплӑ Елена утравӗ',
        'SI' => 'Словени',
        'SJ' => 'Шпицбергенпа Ян-Майен',
        'SK' => 'Словаки',
        'SL' => 'Сьерра-Леоне',
        'SM' => 'Сан-Марино',
        'SN' => 'Сенегал',
        'SO' => 'Сомали',
        'SR' => 'Суринам',
        'SS' => 'Кӑнтӑр Судан',
        'ST' => 'Сан-Томепе Принсипи',
        'SV' => 'Сальвадор',
        'SX' => 'Синт-Мартен',
        'SY' => 'Сири',
        'SZ' => 'Эсватини',
        'TC' => 'Тёркспа Кайкос утравӗсем',
        'TD' => 'Чад',
        'TF' => 'Францин Кӑнтӑр территорийӗсем',
        'TG' => 'Того',
        'TH' => 'Таиланд',
        'TJ' => 'Таджикистан',
        'TK' => 'Токелау',
        'TL' => 'Тухӑҫ Тимор',
        'TM' => 'Туркменистан',
        'TN' => 'Тунис',
        'TO' => 'Тонга',
        'TR' => 'Турци',
        'TT' => 'Тринидадпа Тобаго',
        'TV' => 'Тувалу',
        'TW' => 'Тайвань',
        'TZ' => 'Танзани',
        'UA' => 'Украина',
        'UG' => 'Уганда',
        'UM' => 'АПШ-н тулаш пӗчӗк утравӗсем',
        'US' => 'Пӗрлешнӗ Штатсем',
        'UY' => 'Уругвай',
        'UZ' => 'Узбекистан',
        'VA' => 'Ватикан',
        'VC' => 'Сент-Винсентпа Гренада',
        'VE' => 'Венесуэла',
        'VG' => 'Виргин утравӗсем (Британи)',
        'VI' => 'Виргин утравӗсем (АПШ)',
        'VN' => 'Вьетнам',
        'VU' => 'Вануату',
        'WF' => 'Уоллиспа Футуна',
        'WS' => 'Самоа',
        'YE' => 'Йемен',
        'YT' => 'Майотта',
        'ZA' => 'Кӑнтӑр Африка Республики',
        'ZM' => 'Замби',
        'ZW' => 'Зимбабве',
    ],
];
